System.register(['external-esModule'], (function (exports) {
	'use strict';
	return {
		setters: [function (module) {
			exports('default', module.default);
		}],
		execute: (function () {



		})
	};
}));
